tools:::Rd_package_description("dfsaneacc")
tools:::Rd_package_author("dfsaneacc")
Maintainer: tools:::Rd_package_maintainer("dfsaneacc")
This package includes the function:
dfsaneacc function to solve large-scale nonlinear systems of
equations using a derivative-free approach with sequential
secant acceleration for spectral residual methods.
J. Barzilai, and J. M. Borwein (1988), Two-point step size gradient methods, IMA J Numerical Analysis, 8, 141-148.
E. G. Birgin, J. M. Mart\'inez (2022), Secant acceleration of sequential residual methods for solving large-scale nonlinear systems of equations, SIAM Journal on Numerical Analysis, 60(6), 3145-3180.
W. LaCruz, and M. Raydan (2003), Nonmonotone spectral methods for large-scale nonlinear systems, Optimization Methods and Software, 18, 583-599.
W. LaCruz, J. M. Mart\'inez, and M. Raydan (2006), Spectral residual method without gradient information for solving large-scale nonlinear systems of equations, Mathematics of Computation, 75, 1429-1448.
M. Raydan (1997), Barzilai-Borwein gradient method for large-scale unconstrained minimization problem, SIAM Journal on Optimization, 7, 26-33.